aboutsummaryrefslogtreecommitdiffstats
path: root/os/io/serial.c
diff options
context:
space:
mode:
Diffstat (limited to 'os/io/serial.c')
-rw-r--r--os/io/serial.c12
1 files changed, 10 insertions, 2 deletions
diff --git a/os/io/serial.c b/os/io/serial.c
index 05d258841..30a17ed48 100644
--- a/os/io/serial.c
+++ b/os/io/serial.c
@@ -68,7 +68,15 @@ static const struct SerialDriverVMT vmt = {
};
/**
- * @brief Initializes a generic full duplex driver.
+ * @brief Serial Driver initialization.
+ */
+void sdInit(void) {
+
+ sd_lld_init();
+}
+
+/**
+ * @brief Initializes a generic full duplex driver object.
* @details The HW dependent part of the initialization has to be performed
* outside, usually in the hardware initialization code.
*
@@ -84,7 +92,7 @@ static const struct SerialDriverVMT vmt = {
* some data is written in the Queue. The value can be
* @p NULL.
*/
-void sdInit(SerialDriver *sdp, qnotify_t inotify, qnotify_t onotify) {
+void sdObjectInit(SerialDriver *sdp, qnotify_t inotify, qnotify_t onotify) {
sdp->vmt = &vmt;
chEvtInit(&sdp->d1.ievent);